@@ -457,7 +457,7 @@ Status SetAuthentication (int count, IceListenObj *listenObjs,
     QString iceAuth = QStandardPaths::findExecutable(QStringLiteral("iceauth"));
     if (iceAuth.isEmpty())
     {
-        qWarning("KSMServer: could not find iceauth");
+        qCWarning(KSMSERVER, "KSMServer: could not find iceauth");
         return 0;
     }
 
@@ -487,7 +487,7 @@ void FreeAuthenticationData(int count, IceAuthDataEntry *authDataEntries)
     QString iceAuth = QStandardPaths::findExecutable(QStringLiteral("iceauth"));
     if (iceAuth.isEmpty())
     {
-        qWarning("KSMServer: could not find iceauth");
+        qCWarning(KSMSERVER, "KSMServer: could not find iceauth");
         return;
     }
 
@@ -504,7 +504,7 @@ void FreeAuthenticationData(int count, IceAuthDataEntry *authDataEntries)
 
 static int Xio_ErrorHandler( Display * )
 {
-    qWarning("ksmserver: Fatal IO error: client killed");
+    qCWarning(KSMSERVER, "ksmserver: Fatal IO error: client killed");
 
     // Don't do anything that might require the X connection
     if (the_server)
@@ -650,14 +650,14 @@ KSMServer::KSMServer( const QString& windowManager, InitFlags flags )
                          (SmPointer) this,
                          HostBasedAuthProc, 256, errormsg ) ) {
 
-        qWarning("KSMServer: could not register XSM protocol");
+        qCWarning(KSMSERVER, "KSMServer: could not register XSM protocol");
     }
 
     if (!IceListenForConnections (&numTransports, &listenObjs,
                                   256, errormsg))
     {
-        qWarning("KSMServer: Error listening for connections: %s", errormsg);
-        qWarning("KSMServer: Aborting.");
+        qCWarning(KSMSERVER, "KSMServer: Error listening for connections: %s", errormsg);
+        qCWarning(KSMSERVER, "KSMServer: Aborting.");
         exit(1);
     }
 
@@ -681,8 +681,8 @@ KSMServer::KSMServer( const QString& windowManager, InitFlags flags )
         f = ::fopen(fName.data(), "w+");
         if (!f)
         {
-            qWarning("KSMServer: cannot open %s: %s", fName.data(), strerror(errno));
-            qWarning("KSMServer: Aborting.");
+            qCWarning(KSMSERVER, "KSMServer: cannot open %s: %s", fName.data(), strerror(errno));
+            qCWarning(KSMSERVER, "KSMServer: Aborting.");
             exit(1);
         }
         char* session_manager = IceComposeNetworkIdList(numTransports, listenObjs);
@@ -977,12 +977,9 @@ bool KSMServer::isWM( const KSMClient* client ) const
     return isWM( client->program());
 }
 
-bool KSMServer::isWM( const QString& program ) const
+bool KSMServer::isWM( const QString& command ) const
 {
-    // Strip possible paths, so that even /usr/bin/kwin is recognized as kwin.
-    QString wmName = wm.mid( wm.lastIndexOf( QDir::separator()) + 1 );
-    QString programName = program.mid( program.lastIndexOf( QDir::separator()) + 1 );
-    return programName == wmName;
+    return command == wm;
 }
 
 bool KSMServer::defaultSession() const
@@ -1086,13 +1083,20 @@ void KSMServer::rebootWithoutConfirmation()
 
 void KSMServer::openSwitchUserDialog()
 {
-    KDisplayManager dm;
-    if (!dm.isSwitchable()) {
+    if (dialogActive) {
         return;
     }
 
-    QScopedPointer<KSMSwitchUserDialog> dlg(new KSMSwitchUserDialog(&dm));
-    dlg->exec();
+    QProcess *p = new QProcess(this);
+    p->setProgram(QStringLiteral(SWITCHUSER_GREETER_BIN));
+
+    connect(p, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, [this, p] {
+        p->deleteLater();
+        dialogActive = false;
+    });
+
+    dialogActive = true;
+    p->start();
 }
 
 void KSMServer::runShutdownScripts()
