@@ -24,7 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ******************************************************************/
 
 #include "shutdowndlg.h"
-//include <ksmserver_debug.h>
+#include "ksmserver_debug.h"
 
 #include <QApplication>
 #include <QDesktopWidget>
@@ -172,12 +172,12 @@ void KSMShutdownDlg::init()
         //qCDebug(KSMSERVER) << "Using QML theme" << fileName;
         setSource(QUrl::fromLocalFile(fileName));
     } else {
-        qWarning() << "Couldn't find a theme for the Shutdown dialog" << fileName;
+        qCWarning(KSMSERVER) << "Couldn't find a theme for the Shutdown dialog" << fileName;
         return;
     }
 
     if(!errors().isEmpty()) {
-        qWarning() << errors();
+        qCWarning(KSMSERVER) << errors();
     }
 
     connect(rootObject(), SIGNAL(logoutRequested()), SLOT(slotLogout()));
