@@ -111,7 +111,7 @@ class NotificationThread : public QThread
 
         QString soundFilename = notifyConfig.readEntry(QStringLiteral("Sound"));
         if (soundFilename.isEmpty()) {
-            qWarning() << "Audio notification requested, but no sound file provided in notifyrc file, aborting audio notification";
+            qCWarning(KSMSERVER) << "Audio notification requested, but no sound file provided in notifyrc file, aborting audio notification";
             return;
         }
 
@@ -120,7 +120,7 @@ class NotificationThread : public QThread
             soundURL = QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sounds/") + soundFilename));
 
             if (soundURL.isEmpty()) {
-                qWarning() << "Audio notification requested, but sound file from notifyrc file was not found, aborting audio notification";
+                qCWarning(KSMSERVER) << "Audio notification requested, but sound file from notifyrc file was not found, aborting audio notification";
                 return;
             }
         }
@@ -168,7 +168,7 @@ void KSMServer::restoreSession( const QString &sessionName )
                 wmStartCommands << configSessionGroup.readEntry( QStringLiteral("restartCommand")+n, QStringList() );
             }
         }
-    } 
+    }
     if( wmStartCommands.isEmpty()) // otherwise use the configured default
         wmStartCommands << wmCommands;
 
@@ -223,7 +223,7 @@ void KSMServer::wmProcessChange()
     }
     if( wmProcess->state() == QProcess::NotRunning )
     { // wm failed to launch for some reason, go with kwin instead
-        qWarning() << "Window manager" << wm << "failed to launch";
+        qCWarning(KSMSERVER) << "Window manager" << wm << "failed to launch";
         if( wm == QStringLiteral( KWIN_BIN ) )
             return; // uhoh, kwin itself failed
         qCDebug(KSMSERVER) << "Launching KWin";
@@ -266,7 +266,7 @@ void KSMServer::autoStart0Done()
                                          QStringLiteral( "org.kde.KCMInit" ),
                                          QDBusConnection::sessionBus(), this );
     if( !kcminitSignals->isValid()) {
-        qWarning() << "kcminit not running? If we are running with mobile profile or in another platform other than X11 this is normal.";
+        qCWarning(KSMSERVER) << "kcminit not running? If we are running with mobile profile or in another platform other than X11 this is normal.";
         delete kcminitSignals;
         kcminitSignals = 0;
         QTimer::singleShot(0, this, &KSMServer::kcmPhase1Done);
@@ -405,7 +405,6 @@ void KSMServer::autoStart2()
     waitAutoStart2 = true;
     waitKcmInit2 = true;
     autoStart(2);
-    QTimer::singleShot( 10000, this, &KSMServer::autoStart2Done); //In case klauncher never returns
 
     QDBusInterface kded( QStringLiteral( "org.kde.kded5" ),
                          QStringLiteral( "/kded" ),
@@ -612,7 +611,7 @@ void KSMServer::resumeStartupInternal()
             autoStart2();
           break;
         default:
-            qWarning() << "Unknown resume startup state" ;
+            qCWarning(KSMSERVER) << "Unknown resume startup state" ;
           break;
     }
 }
