@@ -92,7 +92,8 @@ ShellCorona::ShellCorona(QObject *parent)
       m_addPanelAction(nullptr),
       m_addPanelsMenu(nullptr),
       m_interactiveConsole(nullptr),
-      m_waylandPlasmaShell(nullptr)
+      m_waylandPlasmaShell(nullptr),
+      m_closingDown(false)
 {
     setupWaylandIntegration();
     qmlRegisterUncreatableType<DesktopView>("org.kde.plasma.shell", 2, 0, "Desktop", QStringLiteral("It is not possible to create objects of type Desktop"));
@@ -152,6 +153,7 @@ ShellCorona::ShellCorona(QObject *parent)
 
     connect(qApp, &QCoreApplication::aboutToQuit, this, [this]() {
         //saveLayout is a slot but arguments not compatible
+        m_closingDown = true;
         saveLayout();
     });
 
@@ -1065,8 +1067,8 @@ void ShellCorona::removeDesktop(DesktopView *desktopView)
     }
 
     Q_ASSERT(m_desktopViewforId.value(idx) == desktopView);
-    delete desktopView;
     m_desktopViewforId.remove(idx);
+    delete desktopView;
 }
 
 PanelView *ShellCorona::panelView(Plasma::Containment *containment) const
@@ -1301,7 +1303,11 @@ void ShellCorona::panelContainmentDestroyed(QObject *cont)
 {
     auto view = m_panelViews.take(static_cast<Plasma::Containment*>(cont));
     view->deleteLater();
-    emit availableScreenRectChanged();
+    //don't make things relayout when the application is quitting
+    //NOTE: qApp->closingDown() is still false here
+    if (!m_closingDown) {
+        emit availableScreenRectChanged();
+    }
 }
 
 void ShellCorona::handleContainmentAdded(Plasma::Containment *c)
